%global __requires_exclude pkg-config

Summary: System and Service Manager
Name: systemd
Version: 255
Release: 14%{?dist}.ap.2
License: LGPLv2+ and MIT and GPLv2+
Url: https://www.freedesktop.org/wiki/Software/systemd
Source0: https://github.com/systemd/systemd/archive/v%{version}/%{name}-%{version}.tar.gz

Source2: purge-nobody-user
Source3: yum-protect-systemd.conf
Source4: inittab
Source5: sysctl.conf.README
Source6: systemd-journal-remote.xml
Source7: systemd-journal-gatewayd.xml
Source8: 20-yama-ptrace.conf
Source9: systemd-udev-trigger-no-reload.conf
Source10: 20-grubby.install
Source11: systemd-user
Source12: libsystemd-shared.abignore

Source13: 10-oomd-defaults.conf
Source14: 10-oomd-root-slice-defaults.conf
Source15: 10-oomd-user-service-defaults.conf
Source16: disable-privatedevices.conf

Source21: macros.sysusers
Source22: sysusers.attr
Source23: sysusers.prov
Source24: sysusers.generate-pre.sh

Patch0001: fix-CVE-2023-7008.patch
# fix systemd-logind coredump when something wrong happened
# before hashmap_put()
# https://github.com/systemd/systemd/pull/30610
Patch0002: fix-systemd-logind-coredump.patch
# fix wait-online will wait until timeout, even though the configured but offline
# interface.
# https://github.com/systemd/systemd/pull/31184
Patch0003: 0001-wait-online-by-default-not-all-interface-need-to-be-.patch
# fix CVE-2025-4598
# https://github.com/systemd/systemd/commit/0c49e0049b7665bb7769a13ef346fef92e1ad4d6#diff-5e2fa8db8e546031758b40f3b6594e213b0eb414a35233d8bad82dd30e510612
Patch0004: CVE-2025-4598.patch

Patch3000: use-bfq-scheduler.patch

Patch5000: proc-dont-trigger-mount-error-with-invalid-options-o.patch
# 97595710b77aa162ca5e20da57d0a1ed7355eaad
# This commit change the network device renaming logic. We need it to
# rename interfaces to ethX which is not recommended by upstream.
# https://bugs.freedesktop.org/show_bug.cgi?id=53837
Patch5001: revert-udev-network-device-renaming.patch
# keep user's resources after they log out.
Patch5002: logind-set-RemoveIPC-to-false-by-default.patch

%ifarch x86_64 aarch64
%global have_gnu_efi 1
%endif

BuildRequires:  gcc, gcc-c++, coreutils, meson >= 0.43, clang
BuildRequires:  libcap-devel, libmount-devel, libfdisk-devel, dbus-devel, libblkid-devel, /usr/sbin/sfdisk
BuildRequires:  cryptsetup-devel, libgcrypt-devel, pam-devel, libselinux-devel, openssl-devel, audit-libs-devel
BuildRequires:  libseccomp-devel, libpwquality-devel
BuildRequires:  libgpg-error-devel, gnutls-devel, pkgconfig(tss2-esys), pkgconfig(tss2-rc), pkgconfig(tss2-mu), pkgconfig(libfido2)
BuildRequires:  acl, libacl-devel, gobject-introspection-devel, libcurl-devel, libidn2-devel, hostname, gperf, pkgconfig
BuildRequires:  xz-devel, xz, lz4-devel, lz4, bzip2-devel, libzstd-devel, libzstd-devel, libbpf-devel, bpftool
BuildRequires:  kmod-devel,elfutils-devel, iptables-devel, firewalld-filesystem, libmicrohttpd-devel, python3dist(pyelftools)
BuildRequires:  systemtap-sdt-devel, tree, libxkbcommon-devel
BuildRequires:  libxslt, docbook-style-xsl, gawk, gettext, python3dist(pefile)
BuildRequires:  python3dist(lxml), python3dist(jinja2), pkgconfig(bash-completion), perl, perl(IPC::SysV)
%if 0%{?have_gnu_efi}
BuildRequires:  gnu-efi gnu-efi-devel
%endif

%ifarch %{valgrind_arches}
BuildRequires: valgrind-devel
%endif

Requires(post): coreutils
Requires(post): grep
Requires(post): openssl-libs
Requires:       dbus >= 1.9.18
Requires:       (%{name}-rpm-macros = %{version}-%{release} if rpm-build)
Requires:       %{name}-libs = %{version}-%{release}
Requires:       util-linux-core
Provides:       /bin/systemctl, /sbin/shutdown, syslog, systemd-units = %{version}-%{release}
Provides:       system-setup-keyboard = 0.9, systemd-sysv = 206, timedatex = 0.6-3

Recommends:     diffutils
Recommends:     %{name}-pam = %{version}-%{release}
# Don't use systemd-resolved service by default
# Recommends:     %{name}-resolved = %{version}-%{release}
Recommends:     %{name}-networkd = %{version}-%{release}
Recommends:     libidn2.so.0()(64bit)
Recommends:     libidn2.so.0(IDN2_0.0.0)(64bit)
Recommends:     libdw.so.1()(64bit)
Recommends:     libdw.so.1(ELFUTILS_0.186)(64bit)
Recommends:     libelf.so.1()(64bit)
Recommends:     libelf.so.1(ELFUTILS_1.7)(64bit)

Conflicts:      dracut < 059-6

%description
systemd is a system and service manager that runs as PID 1 and starts the rest
of the system. It provides aggressive parallelization capabilities, uses socket
and D-Bus activation for starting services, offers on-demand starting of
daemons, keeps track of processes using Linux control groups, maintains mount
and automount points, and implements an elaborate transactional dependency-based
service control logic. systemd supports SysV and LSB init scripts and works as a
replacement for sysvinit. Other parts of this package are a logging daemon,
utilities to control basic system configuration like the hostname, date, locale,
maintain a list of logged-in users, system accounts, runtime directories and
settings, and a logging daemons.

%package libs
Summary:        systemd libraries
License:        LGPLv2+ and MIT

%description libs
This package provides libraries for systemd and udev.

%package pam
Summary:        systemd PAM module
Requires:       %{name} = %{version}-%{release}

%description pam
This package provides PAM support with systemd-logind.

%package rpm-macros
Summary:        Macros that define paths and scriptlets related to systemd
BuildArch:      noarch

%description rpm-macros
This package provides the systemd-related macros.

%package devel
Summary:        Development headers for systemd
License:        LGPLv2+ and MIT
Requires:       %{name}-libs = %{version}-%{release}
Requires:       %{name}-pam = %{version}-%{release}
Provides:       libudev-devel = %{version}

%description devel
This package provides headers and auxiliary files for developers who need to use
libudev or libsystemd.

%package udev
Summary: Rule-based device node and kernel event manager
License:        LGPLv2+
Requires:       systemd = %{version}-%{release}
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
Requires(post): grep
Requires:       kmod >= 18-4
Requires:       kbd
Provides:       udev = %{version}
Provides:       udev = %{version}
Provides:       u2f-hidraw-policy = 1.0.2-40

Recommends:     libelf.so.1()(64bit)
Recommends:     libelf.so.1(ELFUTILS_1.7)(64bit)
Recommends:     libdw.so.1()(64bit)
Recommends:     libdw.so.1(ELFUTILS_0.186)(64bit)
Recommends:     libtss2-esys.so.0()(64bit)
Recommends:     libtss2-mu.so.0()(64bit)
Recommends:     libtss2-rc.so.0()(64bit)
Suggests:       systemd-bootchart


%description udev
systemd-udevd listens to kernel uevents. For every event, systemd-udevd
executes matching instructions specified in udev rules.The behavior of the daemon
can be configured using udev.conf, its command line options, environment variables,
and on the kernel command line, or changed dynamically with udevadm control.
This package also provides systemd-timesyncd, a network time protocol daemon.

%package container
# Name is the same as in Debian
Summary: Tools for containers and VMs
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-shared = %{version}-%{release}

%description container
This package provides tools to manage containers and virtual machines.


%package journal-remote
Summary:        Tools to send journal events over the network
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}
Requires(pre):    /usr/bin/getent
Requires:       firewalld-filesystem
Provides:       %{name}-journal-gateway = %{version}-%{release}

%description journal-remote
This package provides the ability for programs to read and write journal files
through network, with encrypted HTTP.

%package networkd
Summary:        System daemon that manages network configurations
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}

%description networkd
systemd-networkd is a system service that manages networks. It detects and
configures network devices as they appear, as well as creating virtual network
devices.

%package resolved
Summary:        Network Name Resolution manager
Requires:       %{name} = %{version}-%{release}
Requires:       libidn2.so.0()(64bit)
Requires:       libidn2.so.0(IDN2_0.0.0)(64bit)
Requires(posttrans): grep

%description resolved
systemd-resolved is a system service that provides network name
resolution to local applications. It implements a caching and
validating DNS/DNSSEC stub resolver, as well as an LLMNR and
MulticastDNS resolver and responder.

%package oomd-defaults
Summary:        Configuration files for systemd-oomd
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-shared = %{version}-%{release}
License:        LGPLv2+

%description oomd-defaults
This package provides a system service that uses cgroups-v2 and
pressure stall information (PSI) to monitor and take corrective
action before an OOM occurs in the kernel space.

%package tests
Summary:       Internal unit tests for systemd
Requires:      %{name} = %{version}-%{release}
Requires:      %{name}-shared = %{version}-%{release}
Requires:      %{name}-udev = %{version}-%{release}
Requires:      python3-psutil
License:       LGPLv2+

%description tests
This package provides some built-in tests which can be run to test the
systemd internals.

%package coredump
Summary: tools for storing and retrieving coredumps
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-shared = %{version}-%{release}

%description coredump
This package provides systemd tools for storing and retrieving coredumps:
  * systemd-coredump
  * coredumpctl

%package timesyncd
Summary: minimalistic service to synchronize local time with NTP servers
Requires:       %{name}-shared = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}

%description timesyncd
The package contains the systemd-timesyncd system service that may be used to
synchronize the local system clock with a remote Network Time Protocol server.

%package nss
Summary: nss module providing dynamic user and group name resolution
Requires:       %{name} = %{version}-%{release}
Recommends:     %{name}-container = %{version}-%{release}
Recommends:     %{name}-resolved = %{version}-%{release}
Provides:       nss-myhostname = 0.4

%description nss
systemd-nss is a plug-in module for the GNU Name Service Switch (NSS)
functionality of the GNU C Library (glibc), providing UNIX user and group name
resolution for dynamic users and groups allocated through the DynamicUser=
option in systemd unit files.

%package shared
Summary: systemd shared private library

%description shared
This internal shared library provides common code used by various systemd
components. It is supposed to decrease memory and disk footprint.
The shared library is not meant for public use and is not API or ABI stable.

%package userdbd
Summary: dynamic user/group manager
Requires:       %{name}-shared = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-pam = %{version}-%{release}

%description userdbd
systemd-userdbd is a system service that multiplexes user/group lookups to all
local services that provide JSON user/group record definitions to the system.
In addition it synthesizes JSON user/group records from classic UNIX/glibc NSS
user/group records in order to provide full backwards compatibility. It may
also pick up statically defined JSON user/group records from drop-in files.

%package homed
Summary: home area manager
Requires:       %{name}-shared = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-userdbd = %{version}-%{release}
Requires:       pam

%description homed
systemd-homed is a system service designed to manage home directories. This
package includes the homed service, a PAM module to automatically mount home
directories on user login, tools and documentation.

%package boot
Summary: simple UEFI boot manager - tools and services
Requires:       %{name}-shared = %{version}-%{release}
Requires:       %{name}-boot-efi = %{version}-%{release}

%description boot
systemd-boot (short: sd-boot) is a simple UEFI boot manager. It provides a
textual menu to select the entry to boot and an editor for the kernel command
line. It supports systems with UEFI firmware only.
Installing systemd-boot will configure and install it in the ESP.
This package contains various tools and services to manage systems using
systemd-boot.

%package boot-efi
Summary: simple UEFI boot manager - EFI binaries

%description boot-efi
systemd-boot (short: sd-boot) is a simple UEFI boot manager. It provides a
textual menu to select the entry to boot and an editor for the kernel command
line. It supports systems with UEFI firmware only.
This package contains the EFI binaries.

%package ukify
Summary: tool to build Unified Kernel Images
Requires:       %{name} = %{version}-%{release} python3-pefile

%description ukify
This package provides ukify, a script that combines a kernel image, an initrd,
with a command line, and possibly PCR measurements and other metadata, into a
Unified Kernel Image (UKI).

%package repart
Summary: Provides the systemd-repart utility
Requires:       %{name}-shared = %{version}-%{release}

%description repart
systemd-repart is a configuration-driven system partitioning tool. It follows
the Discoverable Partitions Specification and provides support for encryption
and dm-verity among other things.

%package cryptsetup
Summary: Provides cryptsetup, integritysetup and veritysetup utilities
Requires:       %{name}-shared = %{version}-%{release}

%description cryptsetup
Utilities and units that integrated cryptsetup/integritysetup/veritysetup
support in systemd.

%package manpage
Summary: Provides manpage for all systemd components

%description manpage
All manpage files are provided in this package.

%prep
%autosetup -n %{name}-%{version} -p1

cp %{SOURCE11} src/login/systemd-user.in

%build

CONFIGURE_OPTS=(
        -Dmode=release
        -Dsysvinit-path=/etc/rc.d/init.d
        -Drc-local=/etc/rc.d/rc.local
        -Duser-path=/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin
        -Dservice-watchdog=
        -Ddev-kvm-mode=0666
        -Dkmod=enabled
        -Dblkid=enabled
        -Dfdisk=enabled
        -Dseccomp=enabled
        -Dselinux=enabled
        -Dapparmor=disabled
        -Dpolkit=enabled
        -Dxz=enabled
        -Dzlib=enabled
        -Dbzip2=enabled
        -Dlz4=enabled
        -Dzstd=enabled
        -Dpam=enabled
        -Dacl=enabled
        -Dopenssl=enabled
        -Dcryptolib=openssl
        -Dp11kit=enabled
        -Dgcrypt=enabled
        -Daudit=enabled
        -Delfutils=enabled
        -Dlibcryptsetup=enabled
        -Dqrencode=disabled
        -Dgnutls=enabled
        -Dmicrohttpd=enabled
        -Dlibidn2=enabled
        -Dlibcurl=enabled
        -Dlibfido2=enabled
        -Dxenctrl=disabled
        -Defi=true
        -Dtpm=true
        -Dtpm2=enabled
        -Dhwdb=true
        -Dsysusers=true
        -Ddefault-kill-user-processes=false
        -Dtests=unsafe
        -Dinstall-tests=true
        -Dtty-gid=5
        -Dusers-gid=100
        -Dnobody-user=nobody
        -Dnobody-group=nobody
        -Dsplit-bin=true
        -Db_lto=true
        -Db_ndebug=false
        -Dman=enabled
        -Dversion-tag=v%{version}-%{release}
        -Ddefault-dnssec=no
        -Ddefault-dns-over-tls=no
        -Ddefault-mdns=no
        -Ddefault-llmnr=resolve
        -Dstatus-unit-format-default=combined
        -Doomd=true
        -Dadm-gid=4
        -Daudio-gid=63
        -Dcdrom-gid=11
        -Ddialout-gid=18
        -Ddisk-gid=6
        -Dinput-gid=104
        -Dkmem-gid=9
        -Dkvm-gid=36
        -Dlp-gid=7
        -Drender-gid=105
        -Dsgx-gid=106
        -Dtape-gid=33
        -Dtty-gid=5
        -Dusers-gid=100
        -Dutmp-gid=22
        -Dvideo-gid=39
        -Dwheel-gid=10
        -Dsystemd-journal-gid=190
        -Dsystemd-network-uid=192
        -Dsystemd-resolve-uid=193
)


%meson "${CONFIGURE_OPTS[@]}"
%meson_build

%install
%meson_install

%global system_unit_dir %{_prefix}/lib/systemd/system

install -d %{buildroot}/%{_sbindir}
ln -sf ../bin/udevadm %{buildroot}%{_sbindir}/udevadm

touch %{buildroot}/etc/crypttab
chmod 600 %{buildroot}/etc/crypttab

install -Dm0644 %{SOURCE4} %{buildroot}/etc/
install -Dm0644 %{SOURCE5} %{buildroot}/etc/sysctl.conf
ln -s ../sysctl.conf %{buildroot}/etc/sysctl.d/99-sysctl.conf

install -d %{buildroot}%{system_unit_dir}/basic.target.wants
install -d %{buildroot}%{system_unit_dir}/default.target.wants
install -d %{buildroot}%{system_unit_dir}/dbus.target.wants
install -d %{buildroot}%{system_unit_dir}/syslog.target.wants
install -d %{buildroot}/run
touch %{buildroot}/run/utmp
install -d %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/lastlog
touch %{buildroot}%{_localstatedir}/log/{w,b}tmp
chmod 0664 %{buildroot}%{_localstatedir}/log/lastlog

install -d %{buildroot}%{_prefix}/lib/systemd/system-generators
install -d %{buildroot}%{_prefix}/lib/systemd/user-generators
install -d %{buildroot}%{_prefix}/lib/systemd/system-shutdown/
install -d %{buildroot}%{_prefix}/lib/systemd/system-sleep/

touch %{buildroot}%{_sysconfdir}/hostname
touch %{buildroot}%{_sysconfdir}/vconsole.conf
touch %{buildroot}%{_sysconfdir}/locale.conf
touch %{buildroot}%{_sysconfdir}/machine-id
touch %{buildroot}%{_sysconfdir}/machine-info
touch %{buildroot}%{_sysconfdir}/localtime
install -d %{buildroot}%{_sysconfdir}/X11/xorg.conf.d
touch %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
touch %{buildroot}%{_sysconfdir}/udev/hwdb.bin

install -d %{buildroot}%{_localstatedir}/lib/systemd/{coredump,catalog,backlight,rfkill,linger,timesync,private}
install -d %{buildroot}%{_localstatedir}/lib/private/systemd/journal-upload
install -d %{buildroot}%{_localstatedir}/log/{private,journal}
install -d %{buildroot}%{_localstatedir}/cache/private
install -d %{buildroot}%{system_unit_dir}/systemd-udev-trigger.service.d
install -d %{buildroot}%{system_unit_dir}/{-.slice.d,user@.service.d,systemd-hostnamed.service.d}
install -d %{buildroot}%{_prefix}/lib/systemd/oomd.conf.d
install -d %{buildroot}%{_rpmconfigdir}/{macros.d,fileattrs}
install -d %{buildroot}/usr/lib/firewalld/services
ln -s ../private/systemd/journal-upload %{buildroot}%{_localstatedir}/lib/systemd/journal-upload
touch %{buildroot}%{_localstatedir}/lib/systemd/catalog/database
touch %{buildroot}%{_localstatedir}/lib/systemd/random-seed
touch %{buildroot}%{_localstatedir}/lib/systemd/timesync/clock
touch %{buildroot}%{_localstatedir}/lib/private/systemd/journal-upload/state

install -Dm0644 %{SOURCE3} %{buildroot}/etc/dnf/protected.d/systemd.conf
install -Dm0644 %{SOURCE6} %{SOURCE7} %{buildroot}/usr/lib/firewalld/services/
install -Dm0644 %{SOURCE8} %{buildroot}%{_pkgdocdir}/
install -Dm0644 %{SOURCE9} %{buildroot}%{system_unit_dir}/systemd-udev-trigger.service.d/
install -Dm0644 %{SOURCE14} %{buildroot}%{system_unit_dir}/-.slice.d/
install -Dm0644 %{SOURCE15} %{buildroot}%{system_unit_dir}/user@.service.d/
install -Dm0644 %{SOURCE16} %{buildroot}%{system_unit_dir}/systemd-hostnamed.service.d/

install -Dm0755 %{SOURCE10} %{buildroot}%{_prefix}/lib/kernel/install.d/
install -Dm0644 %{SOURCE12} %{buildroot}%{_prefix}/lib/systemd/
install -D %{SOURCE2} %{buildroot}%{_prefix}/lib/systemd/
install -Dm0644 %{SOURCE13} %{buildroot}%{_prefix}/lib/systemd/oomd.conf.d/

install -Dm0644 %{SOURCE21} %{buildroot}%{_rpmconfigdir}/macros.d/
install -Dm0644 %{SOURCE22} %{buildroot}%{_rpmconfigdir}/fileattrs/
install -Dm0755 %{SOURCE23} %{buildroot}%{_rpmconfigdir}/
install -Dm0755 %{SOURCE24} %{buildroot}%{_rpmconfigdir}/

# we use preset fin release, instead of this.
rm -f %{buildroot}%{_prefix}/lib/systemd/system-preset/90-systemd.preset

%find_lang %{name}


%check
meson test -C %{_vpath_builddir} -t 6 --print-errorlogs

%transfiletriggerin -P 900900 -- /usr/lib/systemd/system /etc/systemd/system
/usr/lib/systemd/systemd-update-helper system-reload-restart || :

%transfiletriggerin -P 900899 -- /usr/lib/systemd/user /etc/systemd/user
if selinuxenabled &>/dev/null; then
  /usr/lib/systemd/systemd-update-helper user-reload-restart 2>/dev/null || :
else
  /usr/lib/systemd/systemd-update-helper user-reload-restart || :
fi

%transfiletriggerun -- /usr/lib/systemd/system /etc/systemd/system
if test -d "/run/systemd/system"; then
    mkdir -p "%{_localstatedir}/lib/rpm-state/systemd"
    touch "%{_localstatedir}/lib/rpm-state/systemd/needs-reload"
fi

%filetriggerpostun -P 1000100 -- /usr/lib/systemd/system /etc/systemd/system
if test -f "%{_localstatedir}/lib/rpm-state/systemd/needs-reload"; then
    rm -rf "%{_localstatedir}/lib/rpm-state/systemd"
    /usr/lib/systemd/systemd-update-helper system-reload || :
fi

%transfiletriggerin -P 1000700 -- /usr/lib/sysusers.d
if test -d "/run/systemd/system"; then
  systemd-sysusers || :
fi

%transfiletriggerin -P 1000700 udev -- /usr/lib/udev/hwdb.d
if test -d "/run/systemd/system"; then
  systemd-hwdb update || :
fi

%transfiletriggerin -P 1000700 -- /usr/lib/systemd/catalog
if test -d "/run/systemd/system"; then
  journalctl --update-catalog || :
fi

%transfiletriggerin -P 1000700 -- /usr/lib/binfmt.d
if test -d "/run/systemd/system"; then
  /usr/lib/systemd/systemd-binfmt || :
fi

%transfiletriggerin -P 1000600 -- /usr/lib/tmpfiles.d
if test -d "/run/systemd/system"; then
  systemd-tmpfiles --create || :
fi

%transfiletriggerin -P 1000600 udev -- /usr/lib/udev/rules.d
if test -e /run/udev/control; then
  udevadm control --reload || :
fi

%transfiletriggerin -P 1000500 -- /usr/lib/sysctl.d
if test -d "/run/systemd/system"; then
  /usr/lib/systemd/systemd-sysctl || :
fi

%post
systemd-machine-id-setup &>/dev/null || :
systemctl daemon-reexec &>/dev/null ||:
journalctl --update-catalog || :

# Exit if not the first install, else go on.
[ $1 -eq 1 ] || exit 0

# only create /var/log/journal during first install to make journal log persistent.
# Not to re-create the directory since user may use volatile mode.
[ -w %{_localstatedir} ] && mkdir -p %{_localstatedir}/log/journal
[ -w %{_localstatedir} ] && journalctl --update-catalog || :

systemd-sysusers || :
systemd-tmpfiles --create &>/dev/null || :
systemctl preset-all &>/dev/null || :
systemctl --global preset-all &>/dev/null || :

%postun
if [ $1 -eq 1 ]; then
   [ -w %{_localstatedir} ] && journalctl --update-catalog || :
   systemd-tmpfiles --create &>/dev/null || :
fi

%systemd_postun_with_restart systemd-journald.service

%global udev_services systemd-udev{d,-settle,-trigger}.service systemd-udevd-{control,kernel}.socket

%postun userdbd
%systemd_postun_with_restart systemd-userdbd.service

%preun oomd-defaults
%systemd_preun systemd-oomd.service

%postun oomd-defaults
%systemd_postun_with_restart systemd-oomd.service

%post oomd-defaults
# make the new org.freedesktop.oom1 API available
if [ -d /run/systemd/system ]; then
    systemctl reload dbus || true
fi

%post udev
mv %{_localstatedir}/lib/random-seed %{_localstatedir}/lib/systemd/random-seed &>/dev/null
mv %{_localstatedir}/lib/backlight %{_localstatedir}/lib/systemd/backlight &>/dev/null
if [ -L %{_localstatedir}/lib/systemd/timesync ]; then
    rm %{_localstatedir}/lib/systemd/timesync
    mv %{_localstatedir}/lib/private/systemd/timesync %{_localstatedir}/lib/systemd/timesync
fi
if [ -f %{_localstatedir}/lib/systemd/clock ] ; then
    mkdir -p %{_localstatedir}/lib/systemd/timesync
    mv %{_localstatedir}/lib/systemd/clock %{_localstatedir}/lib/systemd/timesync/.
fi

udevadm hwdb --update &>/dev/null

%systemd_post %udev_services

/usr/lib/systemd/systemd-random-seed save || :

if [ -f %{_sysconfdir}/vconsole.conf ]; then
sed -i.rpm.bak -r 's/^KEYMAP="?fi-latin[19]"?/KEYMAP="fi"/' /etc/vconsole.conf || :
fi

%preun udev
%systemd_preun %udev_services

%postun udev
%systemd_postun_with_restart systemd-udevd.service

%post boot
%{?have_gnu_efi:%systemd_post systemd-boot-update.service}

%preun boot
%{?have_gnu_efi:%systemd_preun systemd-boot-update.service}

%preun timesyncd
%systemd_preun systemd-timesyncd.service

%post timesyncd
%systemd_post systemd-timesyncd.service

%postun timesyncd
%systemd_postun_with_restart systemd-timesyncd.service


%post journal-remote
%global journal_remote_units_restart systemd-journal-gatewayd.service systemd-journal-remote.service systemd-journal-upload.service
%global journal_remote_units_norestart systemd-journal-gatewayd.socket systemd-journal-remote.socket
%systemd_post %journal_remote_units_restart %journal_remote_units_norestart
%firewalld_reload

%preun journal-remote
%systemd_preun %journal_remote_units_restart %journal_remote_units_norestart
if [ $1 -eq 1 ] ; then
    if [ -f %{_localstatedir}/lib/systemd/journal-upload/state -a ! -L %{_localstatedir}/lib/systemd/journal-upload ] ; then
        mkdir -p %{_localstatedir}/lib/private/systemd/journal-upload
        mv %{_localstatedir}/lib/systemd/journal-upload/state %{_localstatedir}/lib/private/systemd/journal-upload/.
        rmdir %{_localstatedir}/lib/systemd/journal-upload || :
    fi
fi

%postun journal-remote
%systemd_postun_with_restart %journal_remote_units_restart

%post networkd
%systemd_post systemd-networkd.service systemd-networkd-wait-online.service

%preun networkd
%systemd_preun systemd-networkd.service systemd-networkd-wait-online.service

%preun resolved
if [ $1 -eq 0 ] ; then
    systemctl disable --quiet systemd-resolved.service >/dev/null || :
    if ! test -e /etc/resolv.conf; then
        ln -fsv ../run/NetworkManager/resolv.conf /etc/resolv.conf
    fi
fi

%post resolved
[ $1 -gt 1 ] || %systemd_post systemd-resolved.service

%posttrans resolved
# with networkmanager installed, /etc/resolv.conf will automatically be created.
if systemctl -q is-enabled systemd-resolved.service &>/dev/null &&
   ! systemd-analyze cat-config systemd/resolved.conf 2>/dev/null |
        grep -iqE '^DNSStubListener\s*=\s*(no?|false|0|off)\s*$'; then

  if ! test -e /etc/resolv.conf && ! test -L /etc/resolv.conf; then
    ln -sv ../run/systemd/resolve/stub-resolv.conf /etc/resolv.conf || :
  fi
fi

%global _docdir_fmt %{name}

%files -f %{name}.lang
%license LICENSE.GPL2 LICENSE.LGPL2.1
%license LICENSES/MIT.txt
%doc %{_pkgdocdir}
%exclude %{_pkgdocdir}/LICENSE*
%{_sbindir}/init
%{_sbindir}/telinit
%{_sbindir}/runlevel
%{_sbindir}/shutdown
%{_sbindir}/poweroff
%{_sbindir}/reboot
%{_sbindir}/halt
%{_bindir}/busctl
%{_bindir}/hostnamectl
%{_bindir}/journalctl
%{_bindir}/localectl
%{_bindir}/loginctl
%{_bindir}/systemctl
%{_bindir}/systemd-ac-power
%{_bindir}/systemd-analyze
%{_bindir}/systemd-ask-password
%{_bindir}/systemd-cat
%{_bindir}/systemd-cgls
%{_bindir}/systemd-cgtop
%{_bindir}/systemd-confext
%{_bindir}/systemd-creds
%{_bindir}/systemd-delta
%{_bindir}/systemd-detect-virt
%{_bindir}/systemd-escape
%{_bindir}/systemd-firstboot
%{_bindir}/systemd-id128
%{_bindir}/systemd-inhibit
%{_bindir}/systemd-machine-id-setup
%{_bindir}/systemd-mount
%{_bindir}/systemd-notify
%{_bindir}/systemd-path
%{_bindir}/systemd-run
%{_bindir}/systemd-socket-activate
%{_bindir}/systemd-stdio-bridge
%{_bindir}/systemd-sysext
%{_bindir}/systemd-sysusers
%{_bindir}/systemd-tmpfiles
%{_bindir}/systemd-tty-ask-password-agent
%{_bindir}/systemd-umount
%{_bindir}/timedatectl
%{_bindir}/varlinkctl
%ghost %attr(0664,root,root) %verify(not group) %{_rundir}/utmp
%{_sysconfdir}/X11/xinit/xinitrc.d/50-systemd-user.sh
%ghost %config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
%{_sysconfdir}/credstore
%{_sysconfdir}/credstore.encrypted
%{_sysconfdir}/dnf/protected.d/systemd.conf
%ghost %config(noreplace) %{_sysconfdir}/hostname
%{_sysconfdir}/inittab
%ghost %config(noreplace) %{_sysconfdir}/locale.conf
%ghost %config(noreplace) %{_sysconfdir}/localtime
%ghost %attr(0444,root,root) %config(noreplace) %{_sysconfdir}/machine-id
%ghost %config(noreplace) %{_sysconfdir}/machine-info
%{_sysconfdir}/rc.d
%dir %{_sysconfdir}/systemd
%{_sysconfdir}/systemd/system.conf
%{_sysconfdir}/systemd/user.conf
%{_sysconfdir}/systemd/journald.conf
%{_sysconfdir}/systemd/logind.conf
%{_sysconfdir}/systemd/network
%{_sysconfdir}/systemd/system
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/basic.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/bluetooth.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/default.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/getty.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/graphical.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/local-fs.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/machines.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/multi-user.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/network-online.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/printer.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/remote-fs.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/sockets.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/sysinit.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/system-update.target.wants
%ghost %dir %attr(0755,-,-) %{_sysconfdir}/systemd/system/timers.target.wants
%{_sysconfdir}/systemd/user
%{_sysconfdir}/tmpfiles.d
%{_sysconfdir}/xdg/systemd
%{_sysconfdir}/binfmt.d
%{_prefix}/lib/binfmt.d
%{_prefix}/lib/systemd/system/proc-sys-fs-binfmt_misc.automount
%{_prefix}/lib/systemd/system/proc-sys-fs-binfmt_misc.mount
%{_prefix}/lib/systemd/system/systemd-binfmt.service
%{_prefix}/lib/systemd/systemd-binfmt
%{_prefix}/lib/systemd/user-environment-generators/30-systemd-environment-d-generator
%{_prefix}/lib/systemd/user-generators/systemd-xdg-autostart-generator
%{_prefix}/lib/systemd/user-preset/90-systemd.preset
%{_prefix}/lib/credstore
%{_prefix}/lib/environment.d
%{_prefix}/lib/pam.d
%{_prefix}/lib/pcrlock.d
%dir %{_prefix}/lib/systemd
%{_prefix}/lib/systemd/catalog
%ghost %{_localstatedir}/lib/systemd/catalog/database
%{_prefix}/lib/systemd/libsystemd-shared.abignore
%dir %{_prefix}/lib/systemd/network
%{_prefix}/lib/systemd/network/89-ethernet.network.example
%{_prefix}/lib/systemd/ntp-units.d
%{_prefix}/lib/systemd/purge-nobody-user
%{_prefix}/lib/systemd/resolv.conf
%dir %{_prefix}/lib/systemd/system
%dir %{_prefix}/lib/systemd/system-generators
%{_prefix}/lib/systemd/system-generators/systemd-debug-generator
%{_prefix}/lib/systemd/system-generators/systemd-fstab-generator
%{_prefix}/lib/systemd/system-generators/systemd-getty-generator
%{_prefix}/lib/systemd/system-generators/systemd-rc-local-generator
%{_prefix}/lib/systemd/system-generators/systemd-run-generator
%{_prefix}/lib/systemd/system-generators/systemd-system-update-generator
%{_prefix}/lib/systemd/system-generators/systemd-sysv-generator
%{_prefix}/lib/systemd/system-preset
%{_prefix}/lib/systemd/system-shutdown
%{_prefix}/lib/systemd/system/-.slice.d
%{_prefix}/lib/systemd/system/autovt@.service
%{_prefix}/lib/systemd/system/basic.target
%{_prefix}/lib/systemd/system/basic.target.wants
%{_prefix}/lib/systemd/system/blockdev@.target
%{_prefix}/lib/systemd/system/bluetooth.target
%{_prefix}/lib/systemd/system/boot-complete.target
%{_prefix}/lib/systemd/system/console-getty.service
%{_prefix}/lib/systemd/system/container-getty@.service
%{_prefix}/lib/systemd/system/ctrl-alt-del.target
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.hostname1.service
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.locale1.service
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.login1.service
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.timedate1.service
%{_prefix}/lib/systemd/system/dbus.target.wants
%{_prefix}/lib/systemd/system/debug-shell.service
%{_prefix}/lib/systemd/system/default.target
%{_prefix}/lib/systemd/system/default.target.wants
%{_prefix}/lib/systemd/system/dev-hugepages.mount
%{_prefix}/lib/systemd/system/dev-mqueue.mount
%{_prefix}/lib/systemd/system/emergency.service
%{_prefix}/lib/systemd/system/emergency.target
%{_prefix}/lib/systemd/system/exit.target
%{_prefix}/lib/systemd/system/factory-reset.target
%{_prefix}/lib/systemd/system/final.target
%{_prefix}/lib/systemd/system/first-boot-complete.target
%{_prefix}/lib/systemd/system/getty-pre.target
%{_prefix}/lib/systemd/system/getty.target
%{_prefix}/lib/systemd/system/getty@.service
%{_prefix}/lib/systemd/system/graphical.target
%{_prefix}/lib/systemd/system/graphical.target.wants
%{_prefix}/lib/systemd/system/halt.target
%{_prefix}/lib/systemd/system/initrd-cleanup.service
%{_prefix}/lib/systemd/system/initrd-fs.target
%{_prefix}/lib/systemd/system/initrd-parse-etc.service
%{_prefix}/lib/systemd/system/initrd-root-device.target
%{_prefix}/lib/systemd/system/initrd-root-device.target.wants
%{_prefix}/lib/systemd/system/initrd-root-fs.target
%{_prefix}/lib/systemd/system/initrd-root-fs.target.wants
%{_prefix}/lib/systemd/system/initrd-switch-root.service
%{_prefix}/lib/systemd/system/initrd-switch-root.target
%{_prefix}/lib/systemd/system/initrd-usr-fs.target
%{_prefix}/lib/systemd/system/initrd.target
%{_prefix}/lib/systemd/system/initrd.target.wants
%{_prefix}/lib/systemd/system/kexec.target
%{_prefix}/lib/systemd/system/ldconfig.service
%{_prefix}/lib/systemd/system/local-fs-pre.target
%{_prefix}/lib/systemd/system/local-fs.target
%{_prefix}/lib/systemd/system/local-fs.target.wants
%{_prefix}/lib/systemd/system/modprobe@.service
%{_prefix}/lib/systemd/system/multi-user.target
%{_prefix}/lib/systemd/system/multi-user.target.wants
%{_prefix}/lib/systemd/system/network-online.target
%{_prefix}/lib/systemd/system/network-pre.target
%{_prefix}/lib/systemd/system/network.target
%{_prefix}/lib/systemd/system/nss-lookup.target
%{_prefix}/lib/systemd/system/nss-user-lookup.target
%{_prefix}/lib/systemd/system/paths.target
%{_prefix}/lib/systemd/system/poweroff.target
%{_prefix}/lib/systemd/system/printer.target
%{_prefix}/lib/systemd/system/rc-local.service
%{_prefix}/lib/systemd/system/reboot.target
%{_prefix}/lib/systemd/system/remote-fs-pre.target
%{_prefix}/lib/systemd/system/remote-fs.target
%{_prefix}/lib/systemd/system/remote-fs.target.wants
%{_prefix}/lib/systemd/system/rescue.service
%{_prefix}/lib/systemd/system/rescue.target
%{_prefix}/lib/systemd/system/rescue.target.wants
%{_prefix}/lib/systemd/system/rpcbind.target
%{_prefix}/lib/systemd/system/runlevel0.target
%{_prefix}/lib/systemd/system/runlevel*.target
%{_prefix}/lib/systemd/system/runlevel*.target.wants
%{_prefix}/lib/systemd/system/serial-getty@.service
%{_prefix}/lib/systemd/system/shutdown.target
%{_prefix}/lib/systemd/system/sigpwr.target
%{_prefix}/lib/systemd/system/slices.target
%{_prefix}/lib/systemd/system/smartcard.target
%{_prefix}/lib/systemd/system/sockets.target
%dir %{_prefix}/lib/systemd/system/sockets.target.wants
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-initctl.socket
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-journald-dev-log.socket
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-journald.socket
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-pcrextend.socket
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-sysext.socket
%{_prefix}/lib/systemd/system/soft-reboot.target
%{_prefix}/lib/systemd/system/sound.target
%{_prefix}/lib/systemd/system/storage-target-mode.target
%{_prefix}/lib/systemd/system/swap.target
%{_prefix}/lib/systemd/system/sys-fs-fuse-connections.mount
%{_prefix}/lib/systemd/system/sys-kernel-config.mount
%{_prefix}/lib/systemd/system/sys-kernel-debug.mount
%{_prefix}/lib/systemd/system/sys-kernel-tracing.mount
%{_prefix}/lib/systemd/system/sysinit.target
%dir %{_prefix}/lib/systemd/system/sysinit.target.wants
%{_prefix}/lib/systemd/system/sysinit.target.wants/dev-hugepages.mount
%{_prefix}/lib/systemd/system/sysinit.target.wants/dev-mqueue.mount
%{_prefix}/lib/systemd/system/sysinit.target.wants/ldconfig.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/sys-fs-fuse-connections.mount
%{_prefix}/lib/systemd/system/sysinit.target.wants/sys-kernel-config.mount
%{_prefix}/lib/systemd/system/sysinit.target.wants/sys-kernel-debug.mount
%{_prefix}/lib/systemd/system/sysinit.target.wants/sys-kernel-tracing.mount
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-ask-password-console.path
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-firstboot.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-journal-catalog-update.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-journal-flush.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-journald.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-machine-id-commit.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-pcrmachine.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-pcrphase-sysinit.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-pcrphase.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-sysusers.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-tmpfiles-setup.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-tpm2-setup-early.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-tpm2-setup.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-update-done.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-update-utmp.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/kmod-static-nodes.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/proc-sys-fs-binfmt_misc.automount
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-binfmt.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-modules-load.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-random-seed.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-sysctl.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-tmpfiles-setup-dev-early.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-tmpfiles-setup-dev.service
%{_prefix}/lib/systemd/system/syslog.socket
%{_prefix}/lib/systemd/system/syslog.target.wants
%{_prefix}/lib/systemd/system/system-update-cleanup.service
%{_prefix}/lib/systemd/system/system-update-pre.target
%{_prefix}/lib/systemd/system/system-update.target
%{_prefix}/lib/systemd/system/systemd-ask-password-console.path
%{_prefix}/lib/systemd/system/systemd-ask-password-console.service
%{_prefix}/lib/systemd/system/systemd-ask-password-wall.path
%{_prefix}/lib/systemd/system/systemd-ask-password-wall.service
%{_prefix}/lib/systemd/system/systemd-battery-check.service
%{_prefix}/lib/systemd/system/systemd-boot-check-no-failures.service
%{_prefix}/lib/systemd/system/systemd-confext.service
%{_prefix}/lib/systemd/system/systemd-exit.service
%{_prefix}/lib/systemd/system/systemd-firstboot.service
%{_prefix}/lib/systemd/system/systemd-halt.service
%{_prefix}/lib/systemd/system/systemd-hostnamed.service
%{_prefix}/lib/systemd/system/systemd-hostnamed.service.d
%{_prefix}/lib/systemd/system/systemd-initctl.service
%{_prefix}/lib/systemd/system/systemd-initctl.socket
%{_prefix}/lib/systemd/system/systemd-journal-catalog-update.service
%{_prefix}/lib/systemd/system/systemd-journal-flush.service
%{_prefix}/lib/systemd/system/systemd-journald-audit.socket
%{_prefix}/lib/systemd/system/systemd-journald-dev-log.socket
%{_prefix}/lib/systemd/system/systemd-journald-varlink@.socket
%{_prefix}/lib/systemd/system/systemd-journald.service
%{_prefix}/lib/systemd/system/systemd-journald.socket
%{_prefix}/lib/systemd/system/systemd-journald@.service
%{_prefix}/lib/systemd/system/systemd-journald@.socket
%{_prefix}/lib/systemd/system/systemd-kexec.service
%{_prefix}/lib/systemd/system/systemd-localed.service
%{_prefix}/lib/systemd/system/systemd-logind.service
%{_prefix}/lib/systemd/system/systemd-machine-id-commit.service
%{_prefix}/lib/systemd/system/systemd-network-generator.service
%{_prefix}/lib/systemd/system/systemd-pcrextend.socket
%{_prefix}/lib/systemd/system/systemd-pcrextend@.service
%{_prefix}/lib/systemd/system/systemd-pcrfs-root.service
%{_prefix}/lib/systemd/system/systemd-pcrfs@.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-file-system.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-firmware-code.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-firmware-config.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-machine-id.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-make-policy.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-secureboot-authority.service
%{_prefix}/lib/systemd/system/systemd-pcrlock-secureboot-policy.service
%{_prefix}/lib/systemd/system/systemd-pcrmachine.service
%{_prefix}/lib/systemd/system/systemd-pcrphase-initrd.service
%{_prefix}/lib/systemd/system/systemd-pcrphase-sysinit.service
%{_prefix}/lib/systemd/system/systemd-pcrphase.service
%{_prefix}/lib/systemd/system/systemd-poweroff.service
%{_prefix}/lib/systemd/system/systemd-reboot.service
%{_prefix}/lib/systemd/system/systemd-soft-reboot.service
%{_prefix}/lib/systemd/system/systemd-storagetm.service
%{_prefix}/lib/systemd/system/systemd-sysext.service
%{_prefix}/lib/systemd/system/systemd-sysext.socket
%{_prefix}/lib/systemd/system/systemd-sysext@.service
%{_prefix}/lib/systemd/system/systemd-sysusers.service
%{_prefix}/lib/systemd/system/systemd-timedated.service
%{_prefix}/lib/systemd/system/systemd-tmpfiles-clean.service
%{_prefix}/lib/systemd/system/systemd-tmpfiles-clean.timer
%{_prefix}/lib/systemd/system/systemd-tmpfiles-setup.service
%{_prefix}/lib/systemd/system/systemd-tpm2-setup-early.service
%{_prefix}/lib/systemd/system/systemd-tpm2-setup.service
%{_prefix}/lib/systemd/system/systemd-update-done.service
%{_prefix}/lib/systemd/system/systemd-update-utmp-runlevel.service
%{_prefix}/lib/systemd/system/systemd-update-utmp.service
%{_prefix}/lib/systemd/system/systemd-user-sessions.service
%{_prefix}/lib/systemd/system/time-set.target
%{_prefix}/lib/systemd/system/time-sync.target
%{_prefix}/lib/systemd/system/timers.target
%{_prefix}/lib/systemd/system/timers.target.wants
%{_prefix}/lib/systemd/system/tmp.mount
%{_prefix}/lib/systemd/system/umount.target
%{_prefix}/lib/systemd/system/usb-gadget.target
%{_prefix}/lib/systemd/system/user-.slice.d
%{_prefix}/lib/systemd/system/user-runtime-dir@.service
%{_prefix}/lib/systemd/system/user.slice
%{_prefix}/lib/systemd/system/user@.service
%{_prefix}/lib/systemd/system/user@.service.d
%{_prefix}/lib/systemd/system/user@0.service.d
%{_prefix}/lib/systemd/systemd
%{_prefix}/lib/systemd/systemd-battery-check
%{_prefix}/lib/systemd/systemd-boot-check-no-failures
%{_prefix}/lib/systemd/systemd-cgroups-agent
%{_prefix}/lib/systemd/systemd-executor
%{_prefix}/lib/systemd/systemd-hostnamed
%{_prefix}/lib/systemd/systemd-initctl
%{_prefix}/lib/systemd/systemd-journald
%{_prefix}/lib/systemd/systemd-localed
%{_prefix}/lib/systemd/systemd-logind
%{_prefix}/lib/systemd/systemd-measure
%{_prefix}/lib/systemd/systemd-network-generator
%{_prefix}/lib/systemd/systemd-pcrextend
%{_prefix}/lib/systemd/systemd-pcrlock
%{_prefix}/lib/systemd/systemd-reply-password
%{_prefix}/lib/systemd/systemd-shutdown
%{_prefix}/lib/systemd/systemd-socket-proxyd
%{_prefix}/lib/systemd/systemd-storagetm
%{_prefix}/lib/systemd/systemd-sulogin-shell
%{_prefix}/lib/systemd/systemd-sysroot-fstab-check
%{_prefix}/lib/systemd/systemd-timedated
%{_prefix}/lib/systemd/systemd-tpm2-setup
%{_prefix}/lib/systemd/systemd-update-done
%{_prefix}/lib/systemd/systemd-update-helper
%{_prefix}/lib/systemd/systemd-update-utmp
%{_prefix}/lib/systemd/systemd-user-runtime-dir
%{_prefix}/lib/systemd/systemd-user-sessions
%{_prefix}/lib/systemd/systemd-xdg-autostart-condition
%{_prefix}/lib/systemd/user
%dir %{_prefix}/lib/sysusers.d
%{_prefix}/lib/sysusers.d/README
%{_prefix}/lib/sysusers.d/basic.conf
%{_prefix}/lib/sysusers.d/systemd-journal.conf
%{_prefix}/lib/sysusers.d/systemd-network.conf
%{_prefix}/lib/sysusers.d/systemd-oom.conf
%dir %{_prefix}/lib/tmpfiles.d
%{_prefix}/lib/tmpfiles.d/README
%{_prefix}/lib/tmpfiles.d/credstore.conf
%{_prefix}/lib/tmpfiles.d/etc.conf
%{_prefix}/lib/tmpfiles.d/home.conf
%{_prefix}/lib/tmpfiles.d/journal-nocow.conf
%{_prefix}/lib/tmpfiles.d/legacy.conf
%{_prefix}/lib/tmpfiles.d/portables.conf
%{_prefix}/lib/tmpfiles.d/provision.conf
%{_prefix}/lib/tmpfiles.d/static-nodes-permissions.conf
%{_prefix}/lib/tmpfiles.d/systemd-network.conf
%{_prefix}/lib/tmpfiles.d/systemd-nologin.conf
%{_prefix}/lib/tmpfiles.d/systemd-tmp.conf
%{_prefix}/lib/tmpfiles.d/systemd.conf
%{_prefix}/lib/tmpfiles.d/tmp.conf
%{_prefix}/lib/tmpfiles.d/var.conf
%{_prefix}/lib/tmpfiles.d/x11.conf
%{_prefix}/share/bash-completion/completions/busctl
%{_prefix}/share/bash-completion/completions/hostnamectl
%{_prefix}/share/bash-completion/completions/journalctl
%{_prefix}/share/bash-completion/completions/localectl
%{_prefix}/share/bash-completion/completions/loginctl
%{_prefix}/share/bash-completion/completions/systemctl
%{_prefix}/share/bash-completion/completions/systemd-analyze
%{_prefix}/share/bash-completion/completions/systemd-cat
%{_prefix}/share/bash-completion/completions/systemd-cgls
%{_prefix}/share/bash-completion/completions/systemd-cgtop
%{_prefix}/share/bash-completion/completions/systemd-delta
%{_prefix}/share/bash-completion/completions/systemd-detect-virt
%{_prefix}/share/bash-completion/completions/systemd-dissect
%{_prefix}/share/bash-completion/completions/systemd-id128
%{_prefix}/share/bash-completion/completions/systemd-path
%{_prefix}/share/bash-completion/completions/systemd-run
%{_prefix}/share/bash-completion/completions/systemd-sysext
%{_prefix}/share/bash-completion/completions/timedatectl
%dir %{_prefix}/share/dbus-1/interfaces
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.LogControl1.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.hostname1.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.locale1.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.login1.Manager.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.login1.Seat.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.login1.Session.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.login1.User.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Automount.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Device.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Job.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Manager.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Mount.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Path.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Scope.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Service.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Slice.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Socket.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Swap.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Target.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Timer.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.systemd1.Unit.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.timedate1.xml
%{_prefix}/share/dbus-1/services/org.freedesktop.systemd1.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.hostname1.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.locale1.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.login1.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.systemd1.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.timedate1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.hostname1.conf
%{_prefix}/share/dbus-1/system.d/org.freedesktop.locale1.conf
%{_prefix}/share/dbus-1/system.d/org.freedesktop.login1.conf
%{_prefix}/share/dbus-1/system.d/org.freedesktop.systemd1.conf
%{_prefix}/share/dbus-1/system.d/org.freedesktop.timedate1.conf
%{_prefix}/share/factory
%exclude %{_prefix}/share/factory/etc/vconsole.conf
%{_prefix}/share/polkit-1/actions/org.freedesktop.hostname1.policy
%{_prefix}/share/polkit-1/actions/org.freedesktop.locale1.policy
%{_prefix}/share/polkit-1/actions/org.freedesktop.login1.policy
%{_prefix}/share/polkit-1/actions/org.freedesktop.systemd1.policy
%{_prefix}/share/polkit-1/actions/org.freedesktop.timedate1.policy
%{_prefix}/share/polkit-1/actions/org.freedesktop.timesync1.policy
%dir %{_prefix}/share/systemd
%{_prefix}/share/systemd/kbd-model-map
%{_prefix}/share/systemd/language-fallback-map
%{_prefix}/share/zsh/site-functions/_busctl
%{_prefix}/share/zsh/site-functions/_hostnamectl
%{_prefix}/share/zsh/site-functions/_journalctl
%{_prefix}/share/zsh/site-functions/_localectl
%{_prefix}/share/zsh/site-functions/_loginctl
%{_prefix}/share/zsh/site-functions/_sd_hosts_or_user_at_host
%{_prefix}/share/zsh/site-functions/_sd_machines
%{_prefix}/share/zsh/site-functions/_sd_outputmodes
%{_prefix}/share/zsh/site-functions/_sd_unit_files
%{_prefix}/share/zsh/site-functions/_systemctl
%{_prefix}/share/zsh/site-functions/_systemd
%{_prefix}/share/zsh/site-functions/_systemd-analyze
%{_prefix}/share/zsh/site-functions/_systemd-delta
%{_prefix}/share/zsh/site-functions/_systemd-inhibit
%{_prefix}/share/zsh/site-functions/_systemd-path
%{_prefix}/share/zsh/site-functions/_systemd-run
%{_prefix}/share/zsh/site-functions/_systemd-tmpfiles
%{_prefix}/share/zsh/site-functions/_timedatectl
%ghost %attr(0700,root,root) %{_localstatedir}/cache/private
%ghost %dir %attr(0700,-,-) %{_sharedstatedir}/portables
%ghost %attr(0700,root,root) %dir %{_sharedstatedir}/private
%ghost %dir %{_sharedstatedir}/private/systemd
%ghost %dir %attr(0755,-,-) %{_sharedstatedir}/rpm-state/systemd
%dir %{_sharedstatedir}/systemd
%ghost %{_sharedstatedir}/systemd/linger
%{_sharedstatedir}/systemd/private
%ghost %dir %{_sharedstatedir}/systemd/backlight
%ghost %{_sharedstatedir}/systemd/coredump
%ghost %{_sharedstatedir}/systemd/random-seed
%ghost %{_sharedstatedir}/systemd/rfkill
%ghost %dir %{_sharedstatedir}/systemd/timesync
%ghost %{_sharedstatedir}/systemd/timesync/clock
%ghost %attr(0660,root,root) %verify(not group) %{_localstatedir}/log/btmp
%ghost %dir %verify(not mode group) %{_localstatedir}/log/journal
%ghost %attr(0664,root,root) %verify(not md5 size mtime group) %{_localstatedir}/log/lastlog
%ghost %dir %attr(0700,root,root) %{_localstatedir}/log/private
%ghost %attr(0664,root,root) %verify(not group) %{_localstatedir}/log/wtmp

%files libs
%license LICENSE.LGPL2.1
%{_libdir}/libsystemd.so.0
%{_libdir}/libsystemd.so.0.38.0
%{_libdir}/libudev.so.1
%{_libdir}/libudev.so.1.7.8

%files shared
%dir %{_libdir}/systemd
%{_libdir}/systemd/libsystemd-core-*.so
%{_libdir}/systemd/libsystemd-shared-*.so

%files userdbd
%{_bindir}/userdbctl
%{_prefix}/lib/systemd/systemd-userdbd
%{_prefix}/lib/systemd/system/systemd-userdbd.service
%{_prefix}/lib/systemd/system/systemd-userdbd.socket
%{_prefix}/lib/systemd/systemd-userwork

%files nss
%{_libdir}/libnss_myhostname.so.2
%{_libdir}/libnss_mymachines.so.2
%{_libdir}/libnss_resolve.so.2
%{_libdir}/libnss_systemd.so.2


%files pam
%{_libdir}/security/pam_systemd.so
%{_libdir}/security/pam_systemd_loadkey.so

%files rpm-macros
%{_prefix}/lib/rpm/fileattrs
%{_prefix}/lib/rpm/macros.d/macros.systemd
%{_prefix}/lib/rpm/macros.d/macros.sysusers
%{_prefix}/lib/rpm/sysusers.generate-pre.sh
%{_prefix}/lib/rpm/sysusers.prov


%files resolved
%{_bindir}/systemd-resolve
%{_bindir}/resolvectl
%{_sbindir}/resolvconf
%{_sysconfdir}/systemd/resolved.conf
%{_prefix}/lib/systemd/system/systemd-resolved.service
%{_prefix}/lib/systemd/systemd-resolved
%{_prefix}/lib/sysusers.d/systemd-resolve.conf
%{_prefix}/lib/tmpfiles.d/systemd-resolve.conf
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.resolve1.DnssdService.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.resolve1.Link.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.resolve1.Manager.xml
%{_prefix}/share/dbus-1/system-services/org.freedesktop.resolve1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.resolve1.conf
%{_prefix}/share/polkit-1/actions/org.freedesktop.resolve1.policy
%{_prefix}/share/zsh/site-functions/_resolvectl
%{_prefix}/share/bash-completion/completions/resolvectl
%{_prefix}/share/bash-completion/completions/systemd-resolve

%files ukify
%{_bindir}/ukify
%{_prefix}/lib/kernel/install.d/60-ukify.install
%{_prefix}/lib/systemd/ukify

%files boot
%{_bindir}/bootctl
%{_prefix}/lib/systemd/system-generators/systemd-bless-boot-generator
%{_prefix}/lib/systemd/system/systemd-bless-boot.service
%{_prefix}/lib/systemd/system/systemd-boot-random-seed.service
%{_prefix}/lib/systemd/system/systemd-boot-update.service
%{_prefix}/lib/systemd/systemd-bless-boot
%{_prefix}/share/bash-completion/completions/bootctl
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-boot-random-seed.service

%files boot-efi
%dir %{_prefix}/lib/systemd/boot
%{_prefix}/lib/systemd/boot/*

%files homed
%{_bindir}/homectl
%{_sysconfdir}/systemd/homed.conf
%{_prefix}/lib/systemd/system/systemd-homed-activate.service
%{_prefix}/lib/systemd/system/systemd-homed.service
%{_prefix}/lib/systemd/systemd-homed
%{_prefix}/share/bash-completion/completions/homectl
%{_prefix}/lib/systemd/systemd-homework
%{_prefix}/share/dbus-1/system-services/org.freedesktop.home1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.home1.conf
%{_prefix}/share/polkit-1/actions/org.freedesktop.home1.policy
%{_libdir}/security/pam_systemd_home.so

%files devel
%dir %{_prefix}/include/systemd
%{_prefix}/include/systemd/*
%{_prefix}/include/libudev.h
%{_prefix}/lib/pcrlock.d/*
%{_prefix}/share/pkgconfig/systemd.pc
%{_prefix}/share/pkgconfig/udev.pc
%{_libdir}/libsystemd.so
%{_libdir}/libudev.so
%{_libdir}/pkgconfig/libsystemd.pc
%{_libdir}/pkgconfig/libudev.pc

%files udev
%{_bindir}/kernel-install
%{_bindir}/systemd-hwdb
%{_bindir}/udevadm
%{_sbindir}/udevadm
%ghost %config(noreplace) %{_sysconfdir}/crypttab
%{_sysconfdir}/kernel
%{_sysconfdir}/modules-load.d
%{_sysconfdir}/sysctl.conf
%{_sysconfdir}/sysctl.d
%{_sysconfdir}/systemd/pstore.conf
%{_sysconfdir}/systemd/sleep.conf
%{_sysconfdir}/udev
%ghost %{_sysconfdir}/udev/hwdb.bin
%ghost %config(noreplace) %{_sysconfdir}/vconsole.conf
%dir %{_prefix}/lib/kernel
%{_prefix}/lib/kernel/install.conf
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/20-grubby.install
%{_prefix}/lib/kernel/install.d/50-depmod.install
%{_prefix}/lib/kernel/install.d/90-loaderentry.install
%{_prefix}/lib/kernel/install.d/90-uki-copy.install
%{_prefix}/lib/modprobe.d
%{_prefix}/lib/modules-load.d
%dir %{_prefix}/lib/sysctl.d
%{_prefix}/lib/sysctl.d/README
%{_prefix}/lib/sysctl.d/50-default.conf
%{_prefix}/lib/sysctl.d/50-pid-max.conf
%{_prefix}/lib/systemd/network/99-default.link
%{_prefix}/lib/systemd/system-generators/systemd-gpt-auto-generator
%{_prefix}/lib/systemd/system-generators/systemd-hibernate-resume-generator
%{_prefix}/lib/systemd/system-generators/systemd-veritysetup-generator
%{_prefix}/lib/systemd/system-sleep
%{_prefix}/lib/systemd/system/hibernate.target
%{_prefix}/lib/systemd/system/hybrid-sleep.target
%{_prefix}/lib/systemd/system/initrd-root-device.target.wants/remote-veritysetup.target
%{_prefix}/lib/systemd/system/initrd-udevadm-cleanup-db.service
%{_prefix}/lib/systemd/system/kmod-static-nodes.service
%{_prefix}/lib/systemd/system/quotaon.service
%{_prefix}/lib/systemd/system/sleep.target
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-udevd-control.socket
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-udevd-kernel.socket
%{_prefix}/lib/systemd/system/suspend-then-hibernate.target
%{_prefix}/lib/systemd/system/suspend.target
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-hwdb-update.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-udevd.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-udev-trigger.service
%{_prefix}/lib/systemd/system/systemd-backlight@.service
%{_prefix}/lib/systemd/system/systemd-fsck-root.service
%{_prefix}/lib/systemd/system/systemd-fsck@.service
%{_prefix}/lib/systemd/system/systemd-growfs-root.service
%{_prefix}/lib/systemd/system/systemd-growfs@.service
%{_prefix}/lib/systemd/system/systemd-hibernate-resume.service
%{_prefix}/lib/systemd/system/systemd-hibernate.service
%{_prefix}/lib/systemd/system/systemd-hwdb-update.service
%{_prefix}/lib/systemd/system/systemd-hybrid-sleep.service
%{_prefix}/lib/systemd/system/systemd-modules-load.service
%{_prefix}/lib/systemd/system/systemd-portabled.service
%{_prefix}/lib/systemd/system/systemd-pstore.service
%{_prefix}/lib/systemd/system/systemd-quotacheck.service
%{_prefix}/lib/systemd/system/systemd-random-seed.service
%{_prefix}/lib/systemd/system/systemd-remount-fs.service
%{_prefix}/lib/systemd/system/systemd-rfkill.service
%{_prefix}/lib/systemd/system/systemd-rfkill.socket
%{_prefix}/lib/systemd/system/systemd-suspend-then-hibernate.service
%{_prefix}/lib/systemd/system/systemd-suspend.service
%{_prefix}/lib/systemd/system/systemd-sysctl.service
%{_prefix}/lib/systemd/system/systemd-tmpfiles-setup-dev-early.service
%{_prefix}/lib/systemd/system/systemd-tmpfiles-setup-dev.service
%{_prefix}/lib/systemd/system/systemd-udev-settle.service
%{_prefix}/lib/systemd/system/systemd-udev-trigger.service
%{_prefix}/lib/systemd/system/systemd-udev-trigger.service.d
%{_prefix}/lib/systemd/system/systemd-udevd-control.socket
%{_prefix}/lib/systemd/system/systemd-udevd-kernel.socket
%{_prefix}/lib/systemd/system/systemd-udevd.service
%{_prefix}/lib/systemd/system/systemd-vconsole-setup.service
%{_prefix}/lib/systemd/system/systemd-volatile-root.service
%{_prefix}/lib/systemd/system/veritysetup-pre.target
%{_prefix}/lib/systemd/system/veritysetup.target
%{_prefix}/lib/systemd/systemd-backlight
%{_prefix}/lib/systemd/systemd-fsck
%{_prefix}/lib/systemd/systemd-growfs
%{_prefix}/lib/systemd/systemd-hibernate-resume
%{_prefix}/lib/systemd/systemd-makefs
%{_prefix}/lib/systemd/systemd-modules-load
%{_prefix}/lib/systemd/systemd-portabled
%{_prefix}/lib/systemd/systemd-pstore
%{_prefix}/lib/systemd/systemd-quotacheck
%{_prefix}/lib/systemd/systemd-random-seed
%{_prefix}/lib/systemd/systemd-remount-fs
%{_prefix}/lib/systemd/systemd-rfkill
%{_prefix}/lib/systemd/systemd-sleep
%{_prefix}/lib/systemd/systemd-sysctl
%{_prefix}/lib/systemd/systemd-udevd
%{_prefix}/lib/systemd/systemd-vconsole-setup
%{_prefix}/lib/systemd/systemd-veritysetup
%{_prefix}/lib/systemd/systemd-volatile-root
%{_prefix}/lib/tmpfiles.d/systemd-pstore.conf
%dir %{_prefix}/lib/udev
%{_prefix}/lib/udev/ata_id
%{_prefix}/lib/udev/cdrom_id
%{_prefix}/lib/udev/dmi_memory_id
%{_prefix}/lib/udev/fido_id
%{_prefix}/lib/udev/hwdb.d/*
%{_prefix}/lib/udev/iocost
%{_prefix}/lib/udev/mtd_probe
%{_prefix}/lib/udev/rules.d/*
%{_prefix}/lib/udev/scsi_id
%{_prefix}/lib/udev/v4l_id
%{_prefix}/share/bash-completion/completions/kernel-install
%{_prefix}/share/bash-completion/completions/udevadm
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.home1.Home.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.home1.Manager.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.portable1.Image.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.portable1.Manager.xml
%{_prefix}/share/dbus-1/system-services/org.freedesktop.portable1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.portable1.conf
%{_prefix}/share/factory/etc/vconsole.conf
%{_prefix}/share/polkit-1/actions/org.freedesktop.portable1.policy
%{_prefix}/share/zsh/site-functions/_bootctl
%{_prefix}/share/zsh/site-functions/_kernel-install
%{_prefix}/share/zsh/site-functions/_udevadm

%files timesyncd
%{_sysconfdir}/systemd/timesyncd.conf
%{_prefix}/lib/systemd/systemd-timesyncd
%{_prefix}/lib/sysusers.d/systemd-timesync.conf
%{_prefix}/lib/systemd/ntp-units.d/80-systemd-timesync.list
%{_prefix}/lib/systemd/system/systemd-timesyncd.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.timesync1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.timesync1.conf
%{_prefix}/lib/systemd/system/systemd-time-wait-sync.service
%{_prefix}/lib/systemd/systemd-time-wait-sync

%files coredump
%{_bindir}/coredumpctl
%{_sysconfdir}/systemd/coredump.conf
%{_prefix}/lib/systemd/systemd-coredump
%{_prefix}/lib/sysctl.d/50-coredump.conf
%{_prefix}/lib/sysusers.d/systemd-coredump.conf
%{_prefix}/lib/systemd/system/systemd-coredump.socket
%{_prefix}/lib/systemd/system/systemd-coredump@.service
%{_prefix}/lib/systemd/system/sockets.target.wants/systemd-coredump.socket
%{_prefix}/share/bash-completion/completions/coredumpctl
%{_prefix}/share/zsh/site-functions/_coredumpctl

%files container
%{_bindir}/machinectl
%{_bindir}/portablectl
%{_bindir}/systemd-dissect
%{_bindir}/systemd-vmspawn
%{_bindir}/systemd-nspawn
%{_sbindir}/mount.ddi
%ghost %dir %attr(0700,-,-) %{_sharedstatedir}/machines
%{_prefix}/lib/systemd/systemd-export
%{_prefix}/lib/systemd/systemd-sysupdate
%{_prefix}/lib/systemd/portable
%{_prefix}/lib/systemd/import-pubring.gpg
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.import1.service
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.machine1.service
%{_prefix}/lib/systemd/system/dbus-org.freedesktop.portable1.service
%{_prefix}/lib/systemd/system/machine.slice
%{_prefix}/lib/systemd/system/machines.target
%{_prefix}/lib/systemd/system/machines.target.wants
%{_prefix}/lib/systemd/system/remote-fs.target.wants/var-lib-machines.mount
%{_prefix}/lib/systemd/system/systemd-importd.service
%{_prefix}/lib/systemd/system/systemd-machined.service
%{_prefix}/lib/systemd/system/systemd-nspawn@.service
%{_prefix}/lib/systemd/system/systemd-sysupdate-reboot.service
%{_prefix}/lib/systemd/system/systemd-sysupdate-reboot.timer
%{_prefix}/lib/systemd/system/systemd-sysupdate.service
%{_prefix}/lib/systemd/system/systemd-sysupdate.timer
%{_prefix}/lib/systemd/system/var-lib-machines.mount
%{_prefix}/lib/systemd/systemd-import
%{_prefix}/lib/systemd/systemd-import-fs
%{_prefix}/lib/systemd/systemd-importd
%{_prefix}/lib/systemd/systemd-machined
%{_prefix}/lib/systemd/systemd-pull
%{_prefix}/lib/tmpfiles.d/systemd-nspawn.conf
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.import1.Manager.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.import1.Transfer.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.machine1.Image.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.machine1.Machine.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.machine1.Manager.xml
%{_prefix}/share/dbus-1/system-services/org.freedesktop.import1.service
%{_prefix}/share/dbus-1/system-services/org.freedesktop.machine1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.import1.conf
%{_prefix}/share/dbus-1/system.d/org.freedesktop.machine1.conf
%{_prefix}/share/polkit-1/actions/org.freedesktop.import1.policy
%{_prefix}/share/polkit-1/actions/org.freedesktop.machine1.policy
%{_prefix}/share/zsh/site-functions/_machinectl
%{_prefix}/share/zsh/site-functions/_systemd-nspawn
%{_prefix}/share/bash-completion/completions/portablectl
%{_prefix}/share/bash-completion/completions/systemd-nspawn
%{_prefix}/share/bash-completion/completions/machinectl

%files journal-remote
%{_sysconfdir}//systemd/journal-remote.conf
%{_sysconfdir}//systemd/journal-upload.conf
%{_prefix}/lib/firewalld/services/systemd-journal-gatewayd.xml
%{_prefix}/lib/firewalld/services/systemd-journal-remote.xml
%{_prefix}/lib/systemd/system/systemd-journal-gatewayd.service
%{_prefix}/lib/systemd/system/systemd-journal-gatewayd.socket
%{_prefix}/lib/systemd/system/systemd-journal-remote.service
%{_prefix}/lib/systemd/system/systemd-journal-remote.socket
%{_prefix}/lib/systemd/system/systemd-journal-upload.service
%{_prefix}/lib/systemd/systemd-journal-gatewayd
%{_prefix}/lib/systemd/systemd-journal-remote
%{_prefix}/lib/systemd/systemd-journal-upload
%{_prefix}/lib/sysusers.d/systemd-remote.conf
%{_prefix}/share/systemd/gatewayd
%ghost %dir %{_sharedstatedir}/private/systemd/journal-upload
%ghost %{_sharedstatedir}/private/systemd/journal-upload/state
%ghost %{_sharedstatedir}/systemd/journal-upload
%ghost %dir %{_localstatedir}/log/journal/remote

%files networkd
%{_bindir}/networkctl
%{_sysconfdir}/systemd/networkd.conf
%{_prefix}/lib/systemd/network/80-6rd-tunnel.network
%{_prefix}/lib/systemd/network/80-auto-link-local.network.example
%{_prefix}/lib/systemd/network/80-container-host0.network
%{_prefix}/lib/systemd/network/80-container-vb.network
%{_prefix}/lib/systemd/network/80-container-ve.network
%{_prefix}/lib/systemd/network/80-container-vz.network
%{_prefix}/lib/systemd/network/80-vm-vt.network
%{_prefix}/lib/systemd/network/80-wifi-adhoc.network
%{_prefix}/lib/systemd/network/80-wifi-ap.network.example
%{_prefix}/lib/systemd/network/80-wifi-station.network.example
%{_prefix}/lib/systemd/system/systemd-networkd-wait-online.service
%{_prefix}/lib/systemd/system/systemd-networkd-wait-online@.service
%{_prefix}/lib/systemd/system/systemd-networkd.service
%{_prefix}/lib/systemd/system/systemd-networkd.socket
%{_prefix}/lib/systemd/systemd-networkd
%{_prefix}/lib/systemd/systemd-networkd-wait-online
%{_prefix}/share/bash-completion/completions/networkctl
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.network1.DHCPServer.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.network1.DHCPv4Client.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.network1.DHCPv6Client.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.network1.Link.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.network1.Manager.xml
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.network1.Network.xml
%{_prefix}/share/dbus-1/system-services/org.freedesktop.network1.service
%{_prefix}/share/dbus-1/system.d/org.freedesktop.network1.conf
%{_prefix}/share/polkit-1/actions/org.freedesktop.network1.policy
%{_prefix}/share/polkit-1/rules.d/systemd-networkd.rules
%{_prefix}/share/zsh/site-functions/_networkctl

%files oomd-defaults
%{_bindir}/oomctl
%{_sysconfdir}/systemd/oomd.conf
%{_prefix}/lib/systemd/oomd.conf.d
%{_prefix}/lib/systemd/systemd-oomd
%{_prefix}/lib/systemd/system/systemd-oomd.service
%{_prefix}/lib/systemd/system/systemd-oomd.socket
%{_prefix}/lib/systemd/system/-.slice.d/10-oomd-root-slice-defaults.conf
%{_prefix}/lib/systemd/system/user@.service.d/10-oomd-user-service-defaults.conf
%{_prefix}/share/dbus-1/system.d/org.freedesktop.oom1.conf
%{_prefix}/share/dbus-1/system-services/org.freedesktop.oom1.service
%{_prefix}/share/bash-completion/completions/oomctl
%{_prefix}/share/zsh/site-functions/_oomctl
%{_prefix}/share/dbus-1/interfaces/org.freedesktop.oom1.Manager.xml

%files cryptsetup
%{_bindir}/systemd-cryptsetup
%{_bindir}/systemd-cryptenroll
%{_prefix}/share/bash-completion/completions/systemd-cryptenroll
%{_prefix}/lib/systemd/system-generators/systemd-cryptsetup-generator
%{_prefix}/lib/systemd/systemd-cryptsetup
%{_prefix}/lib/systemd/system/system-systemd\x2dcryptsetup.slice
%{_prefix}/lib/systemd/system/system-systemd\x2dveritysetup.slice
%{_prefix}/lib/systemd/system/remote-cryptsetup.target
%{_prefix}/lib/systemd/system/remote-veritysetup.target
%{_prefix}/lib/systemd/system/initrd-root-device.target.wants/remote-cryptsetup.target
%{_prefix}/lib/systemd/system/cryptsetup-pre.target
%{_prefix}/lib/systemd/system/cryptsetup.target
%{_prefix}/lib/systemd/system-generators/systemd-integritysetup-generator
%{_prefix}/lib/systemd/systemd-integritysetup
%{_prefix}/lib/systemd/system/integritysetup-pre.target
%{_prefix}/lib/systemd/system/integritysetup.target
%{_prefix}/lib/systemd/system/sysinit.target.wants/cryptsetup.target
%{_prefix}/lib/systemd/system/sysinit.target.wants/integritysetup.target
%{_prefix}/lib/systemd/system/sysinit.target.wants/veritysetup.target
%dir %{_libdir}/cryptsetup
%{_libdir}/cryptsetup/libcryptsetup-token-systemd-fido2.so
%{_libdir}/cryptsetup/libcryptsetup-token-systemd-pkcs11.so
%{_libdir}/cryptsetup/libcryptsetup-token-systemd-tpm2.so

%files repart
%{_bindir}/systemd-repart
%{_prefix}/lib/systemd/repart/
%{_prefix}/lib/systemd/system/initrd-root-fs.target.wants/systemd-repart.service
%{_prefix}/lib/systemd/system/sysinit.target.wants/systemd-repart.service
%{_prefix}/lib/systemd/system/systemd-repart.service

%files tests
%dir %{_prefix}/lib/systemd/tests
%{_prefix}/lib/systemd/tests/*

%files manpage
%{_mandir}/*


%changelog
* Fri Jun 13 2025 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 255-14.ap.2
- Applied Autopatch for oc9

* Fri Jun 13 2025 TencentOS Team <tencent_os@tencent.com> - 255-14.ap.1
- Applied Autopatch for ts4

* Wed Jun 04 2025 cunshunxia <cunshunxia@tencent.com> - 255-14
- fix CVE-2025-4598.

* Tue Dec 10 2024 cunshunxia <cunshunxia@tencent.com> - 255-13
- fix systemd-networkd-wait-online unexpected action caused by
- ab3aed4a0349bbaa26f53340770c1b59b463e05d

* Thu Nov 21 2024 cunshunxia <cunshunxia@tencent.com> - 255-12
- fix systemd-logind coredump when something wrong happened before
- hashmap_put()

* Mon Nov 04 2024 Jian Zhao <jackjzhao@tencent.com> - 255-11
- Check valgrind_arches and add valgrind-devel to BuildRequires if matched

* Thu Oct 17 2024 cunshunxia <cunshunxia@tencent.com> - 255-10
- add %ghost of some directories back for compat.

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 255-9
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Sep 06 2024 cunshunxia <cunshunxia@tencent.com> - 255-8
- add libxkbcommon-devel to build requirements.

* Mon Aug 19 2024 cunshunxia <cunshunxia@tencent.com> - 255-7
- split unnecessary binaries and libs to other sub pkgs from main pkg.

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 255-6
- Rebuilt for loongarch release

* Fri Aug 02 2024 cunshunxia <cunshunxia@tencent.com> - 255-5
- fix that when user_00 log out, logind will remove its shm files.

* Mon Apr 08 2024 cunshunxia <cunshunxia@tencent.com> - 255-4
- fix unexpected `preset-all` when upgrade systemd.
- create /var/log/journal at first boot to make log persistent.

* Wed Feb 28 2024 cunshunxia <cunshunxia@tencent.com> - 255-3
- fix fix-CVE-2023-7008.

* Wed Jan 24 2024 cunshunxia <cunshunxia@tencent.com> - 255-2
- restrict dracut version for v255 systemd-executor missing error.

* Wed Jan 17 2024 Upgrade Robot <upbot@opencloudos.org> - 255-1
- Upgrade to version 255

* Tue Jan 16 2024 cunshunxia <cunshunxia@tencent.com> - 253-7
- revert network device renaming change to support udev renaming
- interfaces to ethX.

* Fri Jan 05 2024 cunshunxia <cunshunxia@tencent.com> - 253-6
- fix warning in sysuser.d/basic.conf when systemd upgrade.

* Thu Oct 19 2023 cunshunxia <cunshunxia@tencent.com> - 253-5
- fix CVE-2023-31439 and CVE-2023-31438.

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 253-4
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 253-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 cunshunxia <cunshunxia@tencent.com> - 253-2
- Rebuilt for tpm2-tss 4.0.1

* Tue Jul 11 2023 cunshunxia <cunshunxia@tencent.com> - 253-1
- upgrade to v253.

* Tue May 30 2023 cunshunxia <cunshunxia@tencent.com> - 251-12
- fix vconsole error message when systemd update.

* Wed May 10 2023 cunshunxia <cunshunxia@tencent.com> - 251-11
- add note for posttrans of systemd-resolved.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 251-10
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 21 2023 cunshunxia <cunshunxia@tencent.com> - 251-9
- move lib-core from devel into main pkg.

* Fri Apr 21 2023 cunshunxia <cunshunxia@tencent.com> - 251-8
- remove preset file in systemd.

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 251-7
- Rebuilt for OpenCloudOS Stream 23

* Sun Jan 8 2023 cunshunxia <cunshunxia@tencent.com> - 251-6
- fix resolv.conf cannot be used after anaconda installed.

* Tue Dec 20 2022 cunshunxia <cunshunxia@tencent.com> - 251-5
- fix warning "cgroup2: Unknown parameter 'memory_recursiveprot'"

* Tue Dec 20 2022 cunshunxia <cunshunxia@tencent.com> - 251-4
- dont trigger mount error with invalid options on old kernels.

* Mon Dec 19 2022 cunshunxia <cunshunxia@tencent.com> - 251-3
- work around transfiletrigger problem.

* Fri Dec 9 2022 cunshunxia <cunshunxia@tencent.com> - 251-2
- fix meson build with optimization plain

* Mon Jun 6 2022 cunshunxia <cunshunxia@tencent.com> - 251-1
- initial build
